@@ -1,5 +1,7 @@
 from pyotrs.lib import DynamicField
-from otrs_somconnexio.ticket_exceptions import CustomerVatNumberMissing
+from otrs_somconnexio.otrs_models.telecom_company import TelecomCompany
+from otrs_somconnexio.ticket_exceptions import CustomerMailMissing,\
+    CustomerVatNumberMissing
 
 
 class MobileDynamicFields():
@@ -34,6 +36,9 @@ class MobileDynamicFields():
             self._minutes(),
             self._data(),
             self._service_type(),
+            self._mail(),
+            self._phone(),
+            self._df_previous_provider(),
         ]
 
     def _process_id(self):
@@ -79,3 +84,22 @@ class MobileDynamicFields():
     def _service_type(self):
         type = self.eticom_contract.mobile_option
         return DynamicField("tipusServeiMobil", self.service_type[type])
+
+    def _mail(self):
+        mail = self.eticom_contract.party.get_contact_email()
+        if mail:
+            return DynamicField(name="correuElectronic", value=mail.value)
+        raise CustomerMailMissing(self.eticom_contract.id)
+
+    def _phone(self):
+        """ Return the phone value. If the party does not have phone return 0. """
+        phone = self.eticom_contract.party.get_contact_phone()
+        if phone:
+            return DynamicField(name="telefonContacte", value=phone.value)
+        return None
+
+    def _df_previous_provider(self):
+        return DynamicField(
+            name="operadorDonantMobil",
+            value=str(TelecomCompany('mobile', self.eticom_contract.mobile_telecom_company))
+        )
