@@ -431,11 +431,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
     def test_adsl_coverage_field(self):
         self.eticom_contract.coverage_availability = Mock(spec=[
-            "adsl_coverage",
-            "mm_fiber_coverage",
-            "vdf_fiber_coverage"
+            "adsl",
+            "mm_fiber",
+            "vdf_fiber"
         ])
-        self.eticom_contract.coverage_availability.adsl_coverage = "20"
+        self.eticom_contract.coverage_availability.adsl = "20"
 
         dynamic_fields = ADSLDynamicFields(
             self.eticom_contract,
@@ -448,11 +448,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
     def test_mm_fiber_coverage_field(self):
         self.eticom_contract.coverage_availability = Mock(spec=[
-            "adsl_coverage",
-            "mm_fiber_coverage",
-            "vdf_fiber_coverage"
+            "adsl",
+            "mm_fiber",
+            "vdf_fiber"
         ])
-        self.eticom_contract.coverage_availability.mm_fiber_coverage = "CoberturaMM"
+        self.eticom_contract.coverage_availability.mm_fiber = "CoberturaMM"
 
         dynamic_fields = ADSLDynamicFields(
             self.eticom_contract,
@@ -465,11 +465,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
     def test_vdf_fiber_coverage_field(self):
         self.eticom_contract.coverage_availability = Mock(spec=[
-            "adsl_coverage",
-            "mm_fiber_coverage",
-            "vdf_fiber_coverage"
+            "adsl",
+            "mm_fiber",
+            "vdf_fiber"
         ])
-        self.eticom_contract.coverage_availability.vdf_fiber_coverage = "FibraVdf"
+        self.eticom_contract.coverage_availability.vdf_fiber = "FibraVdf"
 
         dynamic_fields = ADSLDynamicFields(
             self.eticom_contract,
@@ -490,7 +490,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["canviUbicaciomateixTitular"], "yes")
+        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
 
     def test_change_address_field_doent_set(self):
         self.eticom_contract.change_address = False
@@ -502,7 +502,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertNotIn("canviUbicaciomateixTitular", dynamic_fields_dct.keys())
+        self.assertNotIn("canviUbicacioMateixTitular", dynamic_fields_dct.keys())
 
 # Service Dynamic Fields
 
